@@ -650,6 +650,7 @@ struct GraphWalker<'a> {
   maybe_hasher: Option<FastInsecureHasher>,
   seen: HashSet<&'a Url>,
   pending: VecDeque<(&'a Url, bool)>,
+  has_seen_node_builtin: bool,
   roots: Vec<(ModuleSpecifier, MediaType)>,
   missing_diagnostics: tsc::Diagnostics,
 }
@@ -689,6 +690,7 @@ impl<'a> GraphWalker<'a> {
         graph.imports.len() + graph.specifiers_count(),
       ),
       pending: VecDeque::new(),
+      has_seen_node_builtin: false,
       roots: Vec::with_capacity(graph.imports.len() + graph.specifiers_count()),
       missing_diagnostics: Default::default(),
     }
@@ -736,7 +738,14 @@ impl<'a> GraphWalker<'a> {
   /// redirects resolved. We need to include all the emittable files in
   /// the roots, so they get type checked and optionally emitted,
   /// otherwise they would be ignored if only imported into JavaScript.
-  pub fn into_tsc_roots(self) -> TscRoots {
+  pub fn into_tsc_roots(mut self) -> TscRoots {
+    if self.has_seen_node_builtin && !self.roots.is_empty() {
+      // inject a specifier that will force node types to be resolved
+      self.roots.push((
+        ModuleSpecifier::parse("asset:///reference_types_node.d.ts").unwrap(),
+        MediaType::Dts,
+      ));
+    }
     TscRoots {
       roots: self.roots,
       missing_diagnostics: self.missing_diagnostics,
@@ -788,7 +797,7 @@ impl<'a> GraphWalker<'a> {
         Module::Wasm(module) => {
           maybe_module_dependencies = Some(&module.dependencies);
         }
-        Module::Json(_) | Module::Node(_) | Module::Npm(_) => {}
+        Module::Json(_) | Module::Npm(_) => {}
         Module::External(module) => {
           // NPM files for `"nodeModulesDir": "manual"`.
           let media_type = MediaType::from_specifier(&module.specifier);
@@ -796,6 +805,11 @@ impl<'a> GraphWalker<'a> {
             self.roots.push((module.specifier.clone(), media_type));
           }
         }
+        Module::Node(_) => {
+          if !self.has_seen_node_builtin {
+            self.has_seen_node_builtin = true;
+          }
+        }
       }
 
       if module.media_type().is_declaration() {
