@@ -27,6 +27,7 @@ pub use package_json::PackageJsonThreadLocalCache;
 pub use path::PathClean;
 pub use path::UrlOrPath;
 pub use path::UrlOrPathRef;
+pub use resolution::BinValue;
 pub use resolution::IMPORT_CONDITIONS;
 pub use resolution::NodeConditionOptions;
 pub use resolution::NodeResolution;
@@ -39,4 +40,3 @@ pub use resolution::REQUIRE_CONDITIONS;
 pub use resolution::ResolutionMode;
 pub use resolution::parse_npm_pkg_name;
 pub use resolution::resolve_specifier_into_node_modules;
-pub use resolution::types_package_name;
